@@ -27,12 +27,19 @@ static void coroutine_handler (void* obj_self) {
   error_id = env->call_method(env, stack, method, 1, __func__, FILE_NAME, __LINE__);
   
   if (error_id) {
-    void* obj_exception = env->get_exception(env, stack);
-    const char* exception = env->get_chars(env, stack, obj_exception);
+    // Reconstruct the full exception message including stack trace.
+    // The level 0 means the trace starts from the origin of the exception.
+    
+    int32_t scope_id = env->enter_scope(env, stack);
+    
+    void* obj_full_exception_message = env->build_exception_message(env, stack, 0);
     
     fprintf(env->api->runtime->get_spvm_stderr(env->runtime), "[An exception thrown in a goroutine is converted to a warning]\n");
     
-    env->print_stderr(env, stack, obj_exception);
+    // Print the full exception message with stack trace.
+    env->print_stderr(env, stack, obj_full_exception_message);
+    
+    env->leave_scope(env, stack, scope_id);
     
     fprintf(env->api->runtime->get_spvm_stderr(env->runtime), "\n");
   }
@@ -70,7 +77,7 @@ int32_t SPVM__Go__Coroutine__init_coroutine(SPVM_ENV* env, SPVM_VALUE* stack) {
     coroutine_stack = env->new_memory_block(env, stack, sizeof(struct coro_stack));
     
     if (!coro_stack_alloc(coroutine_stack, 0)) {
-      return env->die_v2(env, stack, "coro_stack_alloc failed.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "coro_stack_alloc failed.", __func__, FILE_NAME, __LINE__);
     }
     
     coro_create(coroutine_context, coroutine_handler, obj_self, coroutine_stack->sptr,  coroutine_stack->ssze);
@@ -98,7 +105,7 @@ int32_t SPVM__Go__Coroutine__transfer(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_coroutine_from = stack[0].oval;
   
   if (!obj_coroutine_from) {
-    return env->die_v2(env, stack, "$from must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$from must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   void** coroutine_from_pointer_items = env->get_pointer(env, stack, obj_coroutine_from);
@@ -108,7 +115,7 @@ int32_t SPVM__Go__Coroutine__transfer(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_coroutine_to = stack[1].oval;
   
   if (!obj_coroutine_to) {
-    return env->die_v2(env, stack, "$to must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$to must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   void** coroutine_to_pointer_items = env->get_pointer(env, stack, obj_coroutine_to);
